import { ReactNode, FC } from 'react';
import { AudioTypes } from './entities/audio';
import { DocumentTypes } from './entities/document';
import { ImageTypes } from './entities/image';
import { InputTypes } from './entities/input';
import { VideoTypes } from './entities/video';
import { SizeFormat } from './lib';
type AfterUploadingType<T> = {
    type: T;
    files: Files<T>;
    formData: FormData | null;
};
type InitOptions<T> = {
    defaultPreview?: string;
    formDataName?: string;
    sizeFormat?: SizeFormat;
    onAfterUploading?: (data: AfterUploadingType<T>) => void;
    onOpen?: () => void;
    onClose?: () => void;
    onCloseWithoutFiles?: () => void;
} & InputTypes.Input<T>;
type Files<T> = T extends 'image' ? ImageTypes.ImageProxy : T extends 'audio' ? AudioTypes.AudioProxy : T extends 'video' ? VideoTypes.VideoProxy : DocumentTypes.DocumentProxy;
declare function useFileUploader<T>(options: InitOptions<T>): {
    Uploader: FC<{
        children: ReactNode;
    }>;
    open: () => void;
    files: Files<T>[];
    isLoading: boolean;
    formData: FormData | null;
    clear: () => void;
};
export type { InitOptions, ImageTypes, VideoTypes, AudioTypes, InputTypes, AfterUploadingType };
export default useFileUploader;
